==============
Multiplication
==============

.. currentmodule:: pysphalt.multiplication

.. Don't include inherited members to keep the doc short
.. automodule:: pysphalt.multiplication
    :members:
